#ifndef UTIL_DOT_H
#define UTIL_DOT_H
/***********************************************************************
*
*  Global Include Files
*
***********************************************************************/
#include "machine.h"


/***********************************************************************
*
*  Global Definitions
*
***********************************************************************/

/* General Definitions */
#ifndef FALSE
#define         FALSE                   0
#endif

#ifndef TRUE
#define         TRUE                    1
#endif

#define         MAX_U_32_NUM            0xFFFFFFFF
#ifdef M_PI
#define		PI			M_PI
#endif
#ifndef PI
#define         PI                      3.14159265358979
#endif
#ifdef M_PI_4
#define		PI4			M_PI_4
#else
#define         PI4                     (PI/4)
#endif
#define         PI64                    (PI/64)

#define         SQRT2                   1.4142135623730951454746218587388284504414

#define         MPEG_AUDIO_ID           1
#define		MPEG_PHASE2_LSF		0	/* 1995-07-11 SHN */

#define         BITS_IN_A_BYTE          8
#define         MAX_NAME_SIZE           300
#define         SBLIMIT                 32
#define         SSLIMIT                 18
#define         FFT_SIZE                1024
#define         HAN_SIZE                512
#define         CRC16_POLYNOMIAL        0x8005

/* MPEG Header Definitions - Mode Values */

#define         MPG_MD_STEREO           0
#define         MPG_MD_JOINT_STEREO     1
#define         MPG_MD_DUAL_CHANNEL     2
#define         MPG_MD_MONO             3

/* Mode Extention */

#define         MPG_MD_LR_LR             0
#define         MPG_MD_LR_I              1
#define         MPG_MD_MS_LR             2
#define         MPG_MD_MS_I              3


/* "bit_stream.h" Definitions */

#define         MINIMUM         4    /* Minimum size of the buffer in bytes */
#define         MAX_LENGTH      32   /* Maximum length of word written or
                                        read from bit stream */
#define         BUFFER_SIZE     16384

#define         Min(A, B)       ((A) < (B) ? (A) : (B))
#define         Max(A, B)       ((A) > (B) ? (A) : (B))

/***********************************************************************
*
*  Global Type Definitions
*
***********************************************************************/

/* Structure for Reading Layer II Allocation Tables from File */

typedef struct {
    unsigned long    steps;
    unsigned long    bits;
    unsigned long    group;
    unsigned long    quant;
} sb_alloc, *alloc_ptr;

typedef sb_alloc        al_table[SBLIMIT][16];

/* Header Information Structure */

typedef struct {
    long version;
    long lay;
    long error_protection;
    long bitrate_index;
    long sampling_frequency;
    long padding;
    long extension;
    long mode;
    long mode_ext;
    long copyright;
    long original;
    long emphasis;
} layer, *the_layer;

/* Parent Structure Interpreting some Frame Parameters in Header */

typedef struct {
    layer       *header;        /* raw header information */
    long         actual_mode;    /* when writing IS, may forget if 0 chs */
    al_table    *alloc;         /* bit allocation table read in */
    long         tab_num;        /* number of table as loaded */
    long         stereo;         /* 1 for mono, 2 for stereo */
    long         jsbound;        /* first band of joint stereo coding */
    long         sblimit;        /* total number of sub bands */
} frame_params;


enum byte_order { order_unknown, order_bigEndian, order_littleEndian };
extern enum byte_order NativeByteOrder;

/* "bit_stream.h" Type Definitions */

typedef struct  bit_stream_struc {
    unsigned char*		pbtOutBuf;   /* for .DLL code */
    long 			nOutBufPos;  /* for .DLL code */
    FILE        *pt;            /* pointer to bit stream device */
    unsigned char *buf;         /* bit stream buffer */
    long         buf_size;       /* size of buffer (in number of bytes) */
    unsigned long        totbit;         /* bit counter of bit stream */
    long         buf_byte_idx;   /* pointer to top byte in buffer */
    long         buf_bit_idx;    /* pointer to top bit of top byte in buffer */
    
    /* format of file in rd mode (BINARY/ASCII) */
} Bit_stream_struc;

#include "l3side.h"

/***********************************************************************
*
*  Global Variable External Declarations
*
***********************************************************************/

extern double   s_freq[2][4];
extern long      bitrate[2][3][15];

/***********************************************************************
*
*  Global Function Prototype Declarations
*
***********************************************************************/

extern void           display_bitrates(long layr);
extern long            BitrateIndex(long, long, long,long);
extern long            SmpFrqIndex(long, long*);
extern void           *mem_alloc(unsigned long, char*);
extern void           empty_buffer(Bit_stream_struc*);
extern long            copy_buffer(char *buffer,Bit_stream_struc *bs);
extern void           write_buffer(Bit_stream_struc*);
extern void           open_bit_stream_w(Bit_stream_struc*, char*, long, long);
extern void           close_bit_stream_w(Bit_stream_struc*);
extern void           alloc_buffer(Bit_stream_struc*, long);
extern void           desalloc_buffer(Bit_stream_struc*);
extern void           putbits(Bit_stream_struc*, unsigned long, long);

extern enum byte_order DetermineByteOrder(void);
extern void SwapBytesInWords( short *loc, long words );

extern void 
getframebits(layer *info, long stereo, long *bitsPerFrame, long *mean_bits);
long nint2( double in );

void timestatus(layer *info,long frameNum,long totalframes);
#endif
