/*
 *	Version numbering for LAME.
 *
 *	Copyright (c) 1999 A.L. Faber
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef VRBTAG_H_INCLUDED
#define VRBTAG_H_INCLUDED

/* -----------------------------------------------------------
 * A Vbr header may be present in the ancillary
 * data field of the first frame of an mp3 bitstream
 * The Vbr header (optionally) contains
 *      frames      total number of audio frames in the bitstream
 *      bytes       total number of bytes in the bitstream
 *      toc         table of contents

 * toc (table of contents) gives seek points
 * for random access
 * the ith entry determines the seek point for
 * i-percent duration
 * seek point in bytes = (toc[i]/256.0) * total_bitstream_bytes
 * e.g. half duration seek point = (toc[50]/256.0) * total_bitstream_bytes
 */

#include "l3bitstr.h"

#define FRAMES_FLAG     0x0001
#define BYTES_FLAG      0x0002
#define TOC_FLAG        0x0004
#define VBR_SCALE_FLAG  0x0008

#define NUMTOCENTRIES 100

#define FRAMES_AND_BYTES (FRAMES_FLAG | BYTES_FLAG)

/* structure to receive extracted header */
/* toc may be NULL */
typedef struct
{
    long		h_id;			/* from MPEG header, 0=MPEG2, 1=MPEG1 */
    long		samprate;		/* determined from MPEG header */
    long		flags;			/* from Vbr header data */
    long		frames;			/* total bit stream frames from Vbr header data */
    long		bytes;			/* total bit stream bytes from Vbr header data */
    long		vbr_scale;		/* encoded vbr scale from Vbr header data */
    unsigned char	toc[NUMTOCENTRIES];		/* may be NULL if toc not desired */
}   VBRTAGDATA;

/*  4 bytes for Header Tag
    4 bytes for Header Flags
  100 bytes for entry (NUMTOCENTRIES)
    4 bytes for FRAME SIZE
    4 bytes for STREAM_SIZE
    4 bytes for VBR SCALE. a VBR quality indicator: 0=best 100=worst
   20 bytes for LAME tag.  for example, "LAME3.12 (beta 6)"
___________
  140 bytes
*/

#define VBRHEADERSIZE (NUMTOCENTRIES+4+4+4+4+4)

long GetVbrTag(VBRTAGDATA *pTagData,  unsigned char *buf);
long SeekPoint(unsigned char TOC[NUMTOCENTRIES], long file_bytes, float percent);
long InitVbrTag(Bit_stream_struc* pBs,long nVersion,long nMode, long SampIndex);
long PutVbrTag(char* lpszFileName,long nVbrScale);
void AddVbrFrame(long nStreamPos);


#endif
